@@ -102,7 +102,7 @@
 #' the highest calculated metric and is obtained by the $plot_extreme output, is the
 #' same for all three reference windows.
 #'
-#' @return a list with 13 elements:
+#' @return a list with 14 elements:
 #' \tabular{rll}{
 #'  1 \tab $calculations   \tab a matrix with calculated metrics\cr
 #'  2 \tab $method \tab the character string of a method \cr
@@ -116,7 +116,8 @@
 #'  10 \tab $plot_heatmap    \tab ggplot2 object: a heatmap of calculated metrics\cr
 #'  11 \tab $plot_extreme    \tab ggplot2 object: line plot of a row with the highest value in a matrix of calculated metrics\cr
 #'  12 \tab $plot_specific    \tab ggplot2 object: line plot of a row with a selected window width in a matrix of calculated metrics\cr
-#'  13 \tab $PCA_output    \tab princomp object: the result output of the PCA analysis
+#'  13 \tab $PCA_output    \tab princomp object: the result output of the PCA analysis\cr
+#'  14 \tab $type    \tab the character string describing type of analysis: daily or monthly
 #'}
 #'
 #' @export
@@ -1812,8 +1813,8 @@ for (m in 1:length(empty_list_datasets)){
     final_list[[4]]
 
 
-    plot_heatmapA <- plot_heatmap(final_list, reference_window = reference_window)
-    plot_extremeA <- plot_extreme(final_list, ylimits = ylimits, reference_window = reference_window)
+    plot_heatmapA <- plot_heatmap(final_list, reference_window = reference_window, type = "daily")
+    plot_extremeA <- plot_extreme(final_list, ylimits = ylimits, reference_window = reference_window, type = "daily")
 
     width_sequence = seq(lower_limit, upper_limit)
 
@@ -1845,7 +1846,8 @@ for (m in 1:length(empty_list_datasets)){
                          plot_heatmap = plot_heatmapA,
                          plot_extreme = plot_extremeA,
                          plot_specific = plot_specificA,
-                         PCA_output = PCA_result)
+                         PCA_output = PCA_result,
+                         type = "daily")
     }
 
     if (method == "cor"){
@@ -1858,7 +1860,8 @@ for (m in 1:length(empty_list_datasets)){
                          plot_heatmap = plot_heatmapA,
                          plot_extreme = plot_extremeA,
                          plot_specific = plot_specificA,
-                         PCA_output = PCA_result)
+                         PCA_output = PCA_result,
+                         type = "daily")
     }
 
   return(final_list)
